#! /usr/bin/env python
# -*- coding: utf-8 -*-
"""Python interpretation of utok.
"""
from __future__ import division, print_function, absolute_import, unicode_literals

# Standard libraries.
import argparse
import itertools

__date__ = "2020/06/13 20:22:25 hoel"
__author__ = "Berthold Höllmann"
__copyright__ = "Copyright © 2020 by Berthold Höllmann"
__credits__ = ["Berthold Höllmann"]
__maintainer__ = "Berthold Höllmann"
__email__ = "berhoel@gmail.com"

__version__ = "1.1.0"

PARSER = argparse.ArgumentParser(
    prog="utok", formatter_class=argparse.ArgumentDefaultsHelpFormatter
)
PARSER.add_argument(
    "--delimiter",
    "-s",
    type=str,
    default=":",
    help="""
Allows one to change the delimiter. If you use csh you might want to set your
path with something like: set path = (`utok -s \\  /usr/local/bin $path`) """,
)
PARSER.add_argument(
    "--delete-list",
    "-d",
    type=str,
    help="""\
Allows one to remove tokens from a list, to remove /usr/sbin and . from a path \
in Bourne Shell one might use: PATH=`utok $PATH -d .:/usr/sbin` 
""",
)
PARSER.add_argument("tokens", nargs="+", type=str)
PARSER.add_argument(
    "--version",
    "-V",
    action="version",
    version="%(prog)s {version}".format(version=__version__),
)


def utok(tokens, delimiter=":", delete_list=""):
    """Process token.

The token chains are splitted at `delimiter` into tokens, and then
the tokens joined again using `delimiter` after removing double
tokens.

Args:
    tokens (list[str]): List of strings representing tokens chains.
    delimiter (str): Character used to construct token chains.
    delete_list (str): Chain of tokens to be deleted from `tokens`.

Returns:
    str: Token chain with all tokens.
"""
    res = []
    _delete_list = delete_list.split(delimiter) if delete_list else []
    for t in itertools.chain(*(j.split(delimiter) for j in tokens)):
        if t not in res and t not in _delete_list:
            res.append(t)
    return delimiter.join(res)


def prog():
    """``utok [-s delimiter] [ tokens...  [-d delete-list ] tokens...]``

Processing the command line arguments and executing the joining of
the elements.

Returns:
    str: Newly constructed string.
"""
    args = PARSER.parse_args()

    return utok(args.tokens, delimiter=args.delimiter, delete_list=args.delete_list)


def main():
    """Main entry point for command line.

    Printing the result string.
    """
    print(prog())


if __name__ == "__main__":
    print(prog())

# Local Variables:
# mode: python
# compile-command: "poetry run tox"
# time-stamp-pattern: "30/__date__ = \"%:y/%02m/%02d %02H:%02M:%02S %u\""
# End:



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['utok']
install_requires = \
['sphinx-argparse>=0.2.5,<0.3.0']

entry_points = \
{'console_scripts': ['utok = utok:main']}

setup_kwargs = {
    'name': 'pyutok',
    'version': '1.1.0',
    'description': 'Inspired by a tool I can not find anymore on the internet: utok 1.5. I use it to clean up path settings in large shell script configuration setups.',
    'long_description': "\n==================================\n pyUTok - Unique TOKens in python\n==================================\n\nInspired by a tool I can not find anymore on the internet: utok 1.5. I\nuse it to clean up path settings in large shell script configuration\nsetups.\n\n\nutok has the following options::\n\n\n   usage: utok [-h] [--delimiter DELIMITER] [--delete-list DELETE_LIST] [--version] tokens [tokens ...]\n\n   positional arguments:\n     tokens\n\n   optional arguments:\n     -h, --help            show this help message and exit\n     --delimiter DELIMITER, -s DELIMITER\n                           Allows one to change the delimiter. If you use csh you might want to set your path with something like: set path = (`utok -s \\ /usr/local/bin $path`) (default: :)\n     --delete-list DELETE_LIST, -d DELETE_LIST\n                           Allows one to remove tokens from a list, to remove /usr/sbin and . from a path in Bourne Shell one might use: PATH=`utok $PATH -d .:/usr/sbin` (default: None)\n     --version, -V         show program's version number and exit\n\nHomepage\n========\n\n`<https://python.höllmanns.de/utok/>`_\n\nAvailability\n============\n\nThe latest version should be available at my `GitLab\n<https://gitlab.com/berhoel/python/pyutok>`_ repository, the package\nis avaliable at `pypi <https://pypi.org/project/pyutok/>`_ via ``pip\ninstall pyutok``.\n\nDescription\n===========\n\nutok, Unique TOKens, takes a list of arguments with delimiters and\nreject all duplicate entries. Here is a example using ``MANPATH``:\n\n.. code-block:: shell\n\n    $ echo $MANPATH\n    /usr/man:/usr/local/man\n    $ MANPATH=`utok /home/local/man /usr/local/man $MANPATH /usr/openwin/man`\n    $ export MANPATH\n    $ echo $MANPATH\n    /home/local/man:/usr/local/man:/usr/man:/usr/openwin/man\n\n\nEven though ``/usr/local/man`` was included a second time it is only\nin the ``MANPATH`` once, though it is now before the ``/usr/man``\nentry instead of after it.\n\nThis version adds the ``-d`` option to remove tokens. To remove ``.``\nfrom the ``PATH`` one would do the following:\n\n.. code-block:: shell\n\n    $ echo $PATH\n    /usr/local/bin:.:/usr/bin:/usr/sbin\n    $ PATH=`utok -d .: $PATH`\n    $ echo PATH\n    /usr/local/bin:/usr/bin:/usr/sbin\n    $ export PATH\n\n\nRequested Features\n==================\n\n  * Have a way to to push an element further back in the path. A work\n    around of this would be be something like:\n\n    .. code-block:: shell\n\n      utok `utok a:b:c:d -d b` b\n\n    which returns: ``a:c:d:b``\n\n  * Have a way to include multiple ``-s`` options.\n\nFeedback\n========\n\nComments or bug reports/fixes go to Berthold Höllmann <berhoel@gmail.com>.\n\nCopyright © 2020 Berthold Höllmann <berhoel@gmail.com>\n\nOriginal C version:\nCopyright © 1998 Sven Heinicke <sven@zen.org>",
    'author': 'Berthold Höllmann',
    'author_email': 'berhoel@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://python.xn--hllmanns-n4a.de/utok/',
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
}


setup(**setup_kwargs)
